# Stock Summary

**SKU**: {sku} **Name**: {name}

## Current Stock Levels

| Metric | Quantity |
|--------|----------|
| **In Stock** | {in_stock} |
| **Available** | {available} |
| **Allocated** | {allocated} |
| **On Order** | {on_order} |
| **In Production** | {in_production} |

## Stock Status

{stock_status}

## Location Breakdown

{location_breakdown}

## Next Steps

{next_steps}

______________________________________________________________________

**Status**: Stock check complete
